<?php

declare(strict_types=1);

namespace Drupal\notifier;

use Symfony\Component\DependencyInjection\Compiler\CompilerPassInterface;
use Symfony\Component\DependencyInjection\Compiler\ServiceLocatorTagPass;
use Symfony\Component\DependencyInjection\ContainerBuilder;
use Symfony\Component\DependencyInjection\Reference;

/**
 * Notifier compiler pass.
 */
final class NotifierCompilerPass implements CompilerPassInterface {

  public function process(ContainerBuilder $container): void {
    // Do it here since Drupal's support for
    // !tagged_locator('notifier.channel', 'channel') is wonky.
    // vendor/symfony/framework-bundle/Resources/config/notifier.php:39.
    $references = [];
    foreach ($container->findTaggedServiceIds('notifier.channel') as $serviceId => $tags) {
      // By 'channel'.
      $channel = $tags[0]['channel'] ?? NULL;
      if ($channel === NULL) {
        throw new \LogicException('Notifier channel tag not found.');
      }

      $references[$channel] = new Reference($serviceId);
    }

    $container->getDefinition('notifier')
      ->setArgument(0, ServiceLocatorTagPass::register($container, $references));
  }

}
